import requests
from LegendsLIB import *
class VENOM:
  def get_rest(user):
    info = A7X.info(user)
    IDN=info['ID']

    headerros = {
        'Content-Length': '305',
        'Content-Type': 'application/x-www-form-urlencoded; charset=UTF-8',
        'Host': 'i.instagram.com',
        'Connection': 'Keep-Alive',
        'User-Agent': 'Instagram 6.12.1 Android (25/7.1.2; 160dpi; 383x680; LENOVO/Android-x86; 4242ED1; x86_64; android_x86_64; en_US)',
        # Requests sorts cookies= alphabetically

        'Accept-Language': 'en-US',
        'X-IG-Connection-Type': 'WIFI',
        'X-IG-Capabilities': 'AQ==',
        'Accept-Encoding': 'gzip',
							}
    datada = {
        'ig_sig_key_version': '4',
        "user_id":IDN
							}
    reso = requests.post('https://i.instagram.com/api/v1/accounts/send_password_reset/',headers=headerros, data=datada).json()
    try:
      resto =str(reso['obfuscated_email'])
      return resto
    except:
      this='YOU BLOCKED'
      return this


import os , codecs

from setuptools import setup, find_packages

pkg = os.path.abspath(os.path.dirname(__file__))

with codecs.open(os.path.join(pkg, "README.md"), encoding="utf-8") as fh:
	
    long_description = "\n" + fh.read()


setup(

    name="VENOMgetREST",
    
    version="2.0",
    
    author="Legends",
    
    author_email="Alaaposhnaq@gmail.com",
    
    description = ("For developers"),
    
    long_description_content_type="text/markdown",
    
    url="https://t.me/LegendsLIB",
    
    project_urls={
        "Bug Tracker": "https://github.com/pypa/sampleproject/issues",
    },
    
    long_description=long_description,
    
    packages=find_packages(),
    
    install_requires=['requests'],
    
    keywords=['LegendsLIB'],
    
    classifiers=[
    
        "Development Status :: 1 - Planning",
        
        "Intended Audience :: Developers",
        
        "Programming Language :: Python :: 3",
        
        "Operating System :: Unix",
        
        "Operating System :: MacOS :: MacOS X",
        
        "Operating System :: Microsoft :: Windows",
    ]
)
